bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 7. Aventiure
___________________________________________________ #### Aventivre wie gvnther ze islande #### mit sinen gesellen chom
###### 389 | ### In den selben ziten | so was ir sciff gegan ### der bvrge also nahen | do sah der kvnec stan ### oben in den venstern | vil manege scoene meit ### daz er ir niht erchande | daz was gvnthere leit
###### 390 | ### er vragte sivride | den gesellen sin ### ist iv daz iht chvende | vmb disiv magedin ### di dort her nider scovwent | gein vns vf di flvot ### swi ir herre heize | si sint vil hohe gemvot
###### 391 | ### do sprach der herre sivrit | nv svlt ir tovgen spehn ### vnder den ivnchfrovwen | vnt svlt mir danne iehn ### welhe ir nemen woldet | hetet irs gewalt ### daz tvon ich so sprach gvnther | ein riter chven vnde balt
###### 392 | ### so sihe ich ir eine | in ienem venster stan ### in snewizer waete | div ist so wolgetan ### di welent miniv ovgen | dvrch ir scoenen lip ### ob ich gewalt des hete | si mvese werden min wip
###### 393 | ### dir hat erwelt vil rehte | diner ovgen shin ### ez ist div edel prvnhilt | daz shone magdin ### nach der din herce ringet | der sin vnt ovch der mvt ### elliv ir gebaerde | div dvhte gvntheren gvt
###### 394 | ### do hiez div kvneginne | vz den venstern gan ### ir herliche maegde | sin solden da niht stan ### den vremden an ce sehene | des waren si bereit ### waz do di vrowen taten | daz ist vns sider ovch geseit
###### 395 | ### gegen den vnchvnden | strichen si ir lip ### des ie site heten | div wetlichen wip ### an div engen venster | chomen si gegan ### da si di helde sahen | daz wart dvrch schowen getan
###### 396 | ### ir waren niwan viere | di chomen in daz lant ### sifrit der chvone | ein ros zoch vf den sant ### da sahen dvrch venster | div waetlichen wip ### des dvhte sich getiwert | des kvnech gvntheres lip
###### 397 | ### er habt im da bi zovme | di zierlichen march ### gvot vnt schone | vil michel vnt vil starch ### vnz der chvnich gvnther | in den satel gesaz ### also diente im sifrit | des er doch sit vil gar vergaz
###### 398 | ### do zoch er ovch daz sine | von dem schiffe dan ### er het solhen dienest | vil selten e getan ### daz er bi stegereife | gestvnde helde mer ### daz sahen dvrch div venster | di vrowen schon vnt her
###### 399 | ### reht in einer maze | den helden vil gemeit ### von sneblancher varwe | ir ros vnt ovch ir chleit ### waren vil geliche | ir schilde wolgetan ### di lvhten von den handen | den vil waetlichen man
###### 400 | ### ir setel wol gesteinet | ir fvrbvge smal ### si riten herliche | fvr prvnhilde sal ### daran hiengen schellen | von liehtem golde rot ### si chomen zv dem lande | als ez ir ellen gebot
###### 401 | ### mit spern niwe sliffen | mit swerten wolgetan ### div vf di sporn giengen | den waetlichen man ### di fvrten di vil chvnen | scharpf vnt breit ### daz sach alliz prvnhilt | div vil herliche meit
###### 402 | ### mit in chomen do danchwart | vnt ovch hagene ### wir horen sagen maere | wi di degene ### von rabenswarcer varwe | trvogen richiv chleit ### ir schilde waren schone | michel gvt vnt breit
###### 403 | ### von india dem lande | man sah si steine tragen ### do chos man an ir wete | vil herliche wagen ### si liezen ane hvte | ir schiffel bi der flvot ### svs riten zv der bvrge | di helde chvne vnt gvt
###### 404 | ### sehs vnt ahzech tvrne | si sahen drinne stan ### dri palas wite | vnt einen sal wolgetan ### von edelem marmelsteine | grvne alsam ein gras ### darinne selbe prvnhilt | mit ir ingesinde was
###### 405 | ### div bvrch was entslozzen | vil wite vfgetan ### do lieffen in engegene | di prvnhilde man ### vnt enpfiengen dise geste | in ir vrowen lant ### ir ros hiez man behalten | vnt ir schilde von der hant
###### 406 | ### do sprach ein chameraere | ir svlt vns geben div swert ### vnt ovch di liehten brvnne | des sit ir vngewert ### sprach von tronge hagene | wir wellens selbe tragen ### do begonde im sifrit | davon div rehten mere sagen
###### 407 | ### man pfliget in dirre bvrge | daz wil ich iv sagen ### daz neheine geste | hie waffen svlen tragen ### nv lat si tragen hinnen | daz ist wol getan ### des volgete vil vngerne | hagen gvntheres man
###### 408 | ### man hiez den gesten schenchen | vnt shvf in gemach ### vil manigen snellen rechen | man da ce hove sach ### in fvrstlicher waete | allenthalben gan ### do wart vil michel schowen | an di chvnen getan
###### 409 | ### do wart vrowen prvnhilde | gesaget mit maeren ### daz vnchvnde rechen | da chomen waeren ### in herlicher waete | gevlozen vf dem flvt ### davon begonde vragen | div maget shone vnt gvt
###### 410 | ### ir svlt mich lazzen horen | sprach div chvnegin ### wer di vil vnchvnden | rechen mvgen sin ### di in miner bvrge | so herliche stan ### vnt dvrch welhes liebe | di helde her gevarn han
###### 411 | ### do sprach ein ir gesinde | vrowe ich mach wol iehen ### daz ich ir deheinen | nie mer habe gesehen ### want geliche sifride | einer darvnder stat ### den svlt ir wol enpfahen | daz ist mit triwen min rat
###### 412 | ### der ander der gesellen | der ist so lobelich ### op er gewalt des hete | wol waer er ein chvnich rich ### op witen fvrsten landen | vnd maht er div gehan ### man siht in bi den andern so rehte herliche stan
###### 413 | ### der dritte der gesellen | der ist so grivlich ### vnt doch mit schonem libe | chvneginne rich ### von swinden sinen blichen | der er so vil getvt ### er ist in sinen sinnen | ich waene grimme gemvt
###### 414 | ### der ivngeste darvnder | der ist so lobelich ### magtlicher zvohte | sihe ich den degen rich ### mit gvotem gelezze | so minnechliche stan ### wir mohtenz alle fvrhten | hete im hi iemen iht getan
###### 415 | ### swi plide er pflege der zvhte | vnd swi shone si sin lip ### er mohte wol erweinen | vil waetlichiv wip ### swenner begonde zvrnen | sin lip ist so gestalt ### er ist in allen tvgenden | ein degen chvne vnd balt
###### 416 | ### do sprach div chvneginne | nv brinch mir gewant ### vnt ist der starche sifrit | chomen in diz lant ### dvrch willen miner minne | ez gat im an den lip ### ich fvrhte in niht so sere | daz ich werde sin wip
###### 417 | ### prvnnhilt div schone | wart schiere wol gechleit ### do giench mit ir dannen | vil manich schoniv meit ### wol hvndert oder mere | geciert was ir lip ### ez wolden sehen di geste | div vil waetlichen wip
###### 418 | ### damit giengen degene | da vz islant ### di prvnnhilde rechen | di trvgen swert enhant ### fvmpf hvndert oder mere | daz was den gesten leit ### do stvnden von dem saedele | di helde chvne vnt gemeit
###### 419 | ### do div chvneginne | sifriden sach ### nv mvget ir gerne horen | wi div magt sprah ### sit willechomen sifrit | her in diz lant ### waz meinet iwer reise | gerne het ich daz bechant
###### 420 | ### vil michel iwer genade | min vrov prvnnhilt ### daz ir mich gervchet grvzen | fvrsten tohter milt ### vor disem edelen rechen | der hie vor mir stat ### wand er ist min herre | der eren het ich gerne rat
###### 421 | ### er ist geborn von rine | waz sol ich dir sagen mer ### dvrch di dine liebe | sin wir gevarn her ### der wil dich gerne minnen | swaz im davon geschit ### nv bedenches dich bezite | min herre erlazet dich es niht
###### 422 | ### er ist geheizen gvnther | vnt ist ein chvnich her ### erwurbe er dine minne | ern gerte nihtes mer ### ia gebot mir her ce varne | der reche wolgetan ### moht ich es im geweigert han | ich het iz gerne verlan
###### 423 | ### si sprach ist er din herre | vnt bistv sin man ### div spil div ich im teile | getar er div bestan ### behabt er des meisterschapft | so wird ich sin wip ### vnt ist daz ich gewinne | ez get iv allen an den lip
###### 424 | ### do sprach von tronege hagene | frowe lat vns sehen ### iweriv spil div starchen | e daz iv mvste iehen ### gvnther min herre | da mvst iz herte sin ### er truwet wol erwerben | ein also schone magedin
###### 425 | ### den stein schol er werffen | vnt springen darnach ### den gere mit mir shiezen | lat iv sin niht ce gach ### ir mvget wol hie verliesen | di ere vnd ovch den lip ### des bedenchet ivch vil ebene | sprach daz minnechliche wip
###### 426 | ### sifrit der vil chvne | zv dem kvonege trat ### allen sinen willen | er in reden bat ### gegen der chvneginne | er solde an angest sin ### ich sol ivch wol behivten | vor ir mit den listen min
###### 427 | ### do sprach der chvnech gvnther | chvneginne her ### nv teilet swaz ir gebietet | vnt waeres dannoch mer ### daz bestvnde ich allez | dvrch iwern schonen lip ### min hovbet wil ich verliesen | irn werdet min wip
###### 428 | ### do div chvneginne | sine rede vernam ### des spils bat si gahen | als ir do gezam ### si hiez ir gewinnen | ce strite gvt gewant ### eine prvnne rotes goldes | vnt einen gvoten schildes rant
###### 429 | ### ein waffenhemde siden | daz leit an div meit ### daz in deheinem strite | waffen nie versneit ### von pfellel vzer lybia | ez was vil wolgetan ### von porten lieht gewurhte | sach man schinen daran
###### 430 | ### di zit wart disen rechen | mit gelfe vil gedrevt ### danchwart vnt hagene | di waren vngefrevt ### wi iz dem chvnege ergienge | des sorgete in der mvt ### si dahten vnser reise div | ist vns rechen niht ce gvt
###### 431 | ### di wile was ovch sifrit | der waetliche man ### e iz iemen erfvnde | in daz schif gegan ### da er sine tarnkappen | verborgen ligen vant ### darin slovf er vil schiere | do was er niemen bechant
###### 432 | ### er ilte hin widere | do vant er rechen vil ### da div chvneginne | teilte ir hohen spil ### dar gi er touvgenliche | von listen daz geschach ### alle di da waren | daz in da niemen en sach
###### 433 | ### der rinch der was beceiget | daz spil solde geschen ### vor manigem chvnen rechen | di daz solden sehen ### mer danne siben hvndert | di sah man waffen tragen ### swem an dem spil gelvnge | daz erz di helden solde sagen
###### 434 | ### do was chomen brvnnhilt | gewaffent man di vant ### sam ob si solde striten | vmb elliv chvniges lant ### ia trvch si ob den siden | vil manigen goldes zein ### ir minnechliche varwe | darvnder vil herliche schein
###### 435 | ### do chom ir gesinde | di trvgen dar ce hant ### von al rotem golde | einn schildes rant ### mit stahele herte spangen | vil michel vnt breit ### darvnder spilen wolde | div minnechlichiv meit
###### 436 | ### der vrowen schiltvezel | ein edel porte was ### darvffe lagen steine | grvne sam ein gras ### der lvhte maniger hande | mit schine wider daz golt ### er mvste wesen vil chvne | dem div vrowe wurde holt
###### 437 | ### der schilt was vnder bvkeln | als vns daz ist gesaget ### wol drier spannen diche | den solde tragen div maget ### von stahel vnt ovch von golde | rich er was genvch ### den ir chamaeraere | selbe vierde chvme trvch
###### 438 | ### also der starche hagene | den schilt dar tragen sach ### mit grimmigem mvte | der helt von tronege sprach ### wa nv chvnich gvnther | wie vliese wir den lip ### der ir da gert ce minnen | div ist des tivels wip
###### 439 | ### vernemt noch von ir waete | der haete si genvch ### von azagovch der siden | einen waffenroch si trvch ### edel vnt riche | ab des varwe schein ### von der chvneginne | vil manich herlicher stein
###### 440 | ### do trvch man der vrowen | vil swaere vnd groz ### einen ger vil scharpfen | den si alle cite schoz ### starch vnt vngefvge | michel vnt breit ### der ce sinen ecken | vil harte vreislichen sneit
###### 441 | ### von des geres swere | horet wunder sagen ### wol vierdehalbiv messe | was darzv geslagen ### den trvgen chvme drie | brvnhilde man ### gvnther der edele | vil harte sorgen began
###### 442 | ### er dahte in sinem mvte | waz sol diz wesen ### der tivel vz der helle | wi chvnd er davor genesen ### wer ich ce bvrgenden | mit dem lebene min ### si mvste hie lange | vri vor miner minne sin
###### 443 | ### do sprach hagen brvder | der chvene danchwart ### mich riwet innechlichen | disiv hovevart ### nv hiezen wir ie rechken | wi verliese wir den lip ### svln vns in disen landen | nv vberwinden div wip
###### 444 | ### mich mvet daz harte sere | daz ich chom in diz lant ### vnt haete min brvder hagene | sin waffen an der hant ### vnt ovch ich daz mine | so mohten sampfte gan ### mit ir vebermvete | alle prvnnhilde man
###### 445 | ### daz wizzet sicherlichen | si soldenz wol bewarn ### vnt haet ich tvsent eide | ce einem vride gesworn ### e daz ich sterben saehe | den lieben herren min ### ia mvese den lip verliesen | daz vil schone magedin
###### 446 | ### wir solden vngefangen | wol rvomen diz lant ### sprach do sin brvoder hagene | vnt heten wir daz gewant ### des wir ce der not bedvrffen | vnt ovch div swert vil gvt ### so wurde wol gesenpftet | der starchen vrowen vbermvt
###### 447 | ### wol hort div maget edele | waz der daegen sprach ### mit smilendem munde | si veber ahsel sach ### nv er dvnche si so chvene | so traget in ir gewant ### ir vil scharpffen waffen | gebet den recken an di hant
###### 448 | ### do si div swert gewunnen | also div maget gebot ### der vil chvne danchwart | vor vrevden wart vil rot ### nv spilen swes si wellen | sprah der vil snelle man ### gvnther ist vmbetwungen | sit daz wir vnser waffen han
###### 449 | ### div prvnnhilde sterche | vil grozliche schein ### man trvch ir zv dem ringe | einen swaeren stein ### groz vnt vngefvge | vil michel vnt wel ### in trvgen chvme zwelfe | helde chvne vnt snel
###### 450 | ### den warf si zallen ziten | do si den ger vershoz ### der bvrgenaere sorge | wurden harte groz ### waffen do sprach hagen | waz hat der kvnich ce trvt ### ia sol si in der helle sin | des vebeln tivels brvt
###### 451 | ### an vil wizzen armen | | si di ermel want ### si begonde vazzen | den schilt an der hant ### den ger si hoch zvchte | do giench iz an den strit ### gvnther vnt sifrit | di vorhten prvnnhilde nit
###### 452 | ### vnt waere im sifrit | niht ce helffe chomen ### so hete si dem chvnige | sinen lip benomen ### er gie dar tovgenliche | vnt rvrt im sine hant ### gvnther sine liste | vil sorchenlich ervant
###### 453 | ### waz hat mich gervret | dahte der chvne man ### do sach er allenthalben | vnt vant da niemen stan ### er sprach ich pinz sifrit | der liebe vrivnt din ### vor der chveneginne | soltv gar an angest sin
###### 454 | ### den shilt gip mir von hende | vnt laze mich den tragen ### vnt merche rehte | waz dv mich hores sagen ### nv hab dv di gebaere | div werch wil ich began ### do er in reht erchande | ez was im liebe getan
###### 455 | ### nv hil dv mine liste | di ne soltv niemen sagen ### so mach div chvneginne | vil lvecel iht beiagen ### an dir deheines rvomes | des si doh willen hat ### nv sihtv wi div vrowe | vor dir vnsorchlichen stat
###### 456 | ### do shoz vil chrepftechliche | div herlichiv meit ### vf einen schilt niwen | michel vnt breit ### den trvch an siner hende | daz sigelinde chint ### daz fiwer spranch von stahele | als ez waete der wint
###### 457 | ### des starchen geres snide | al dvrch den schilt gebrach ### daz man di fiwer lovgen | vz den ringen sach ### des shvzzes beide strvochten | di crepftigen man ### wan div tarnkappe | si waeren tote da bestan
###### 458 | ### sifride dem vil chvenen | von munde brast daz plvt ### vil balde spranch er widere | do nam der helt gvt ### den ger den si geschozzen | haete dem helde dvrch den rant ### den frvmte ir do hin widere | des starchen sifrides hant
###### 459 | ### er dahte ich wil niht schiezen | daz schone magedin ### er cherte des geres snide | hinder den rvcke sin ### mit der gerstangen | er shoz vf ir gewant ### daz ez erchlanch vil lvote | von siner ellenthaften hant
###### 460 | ### daz fiwr stovp vz ringen | alsam ez tribe der wint ### den shuz den shoz mit ellen | daz sigmvndes chint ### si ne moht mit ir crefpten | des shvzes niht gestan ### ez en haete der chvnich gvnther | triwen niemer getan
###### 461 | ### prvnnhilt div schone | vil balde si vf gespranch ### gvnther ritter edele | des shvzzes habe danch ### si want er hetez | mit siner chrapft getan ### ir was darnach geslichen | ein verre crehftiger man
###### 462 | ### do gie si hin vil balde | vil zornech was ir mvt ### den stein hvop vil hohe | div edel magt gvt ### si swanch in crepftechliche | vil verre von der hant ### do spranch si nach dem wurffe | ia erclanch ir allez ir gewant
###### 463 | ### der stein der was gevallen | wol zwelf clafter dan ### den wurf den brach mit sprvnge | div maget wolgetan ### dar gie der herre sifrit | da der stein gelach ### gvnther in do wegte | der helt in werffene pfalch
###### 464 | ### sifrit der was chvne | vil crepftech vnt vil lanch ### den stein den warf er verrer | darzv er witer spranch ### von sinen schonen listen | er hete crapft genvch ### daz er mit dem sprvnge | den chvnich gvnthere doh truch
###### 465 | ### der sprvnch der was ergangen | der stein der was gelegen ### do sach man ander niemen | wan gvnther den degen ### prvnnhilt div schone | div wart in zorne rot ### sifrit haete geverret | des chvnich gvntheres tot
###### 466 | ### zv zir ingesinde | ein teil si lvte sprach ### do si gvntheren cent des ringes | wol gesvnden sach ### vil balde chvmt her naher | ir mage vnt mine man ### ir svlt dem chvnige gvnther | alle wesen vndertan
###### 467 | ### do leiten di vil chivnen | div waffen von der hant ### si bvten sich ce fvzen | vz bvrgvnden lant ### gvnther dem richen | vil manich chvene man ### si wanten daz er haete | div spil mit siner crapf getan
###### 468 | ### er grvztes minnechliche | ia was er tvgende rich ### do nam in bi der hende | div magt lobelich ### si erlovbte im daz er da solde | haben gewalt ### des frevte sich do hagene | der daegen chvne vnt balt
###### 469 | ### si bat den ritter edele | mit ir dannen gan ### in den palas witen | also daz wart getan ### do erbot man ez den recken | mit dienste baz ### danchwart vnt hagene | di mvsenz lazen ane haz
###### 470 | ### sifrit der snelle | wise was genvch ### sine tarenkappen | er abe behalten trvch ### do gie er hine wider | da manich vrowe saz ### er sprach zv dem chvnige | vnt tet vil wisliche daz
###### 471 | ### wes pitet ir min herre | wan beginnet ir der spil ### der iv div chvneginne | teilet also vil ### vnt lat vns balde schowen | wi div sin getan ### sam ers niht en wesse | gebarte der listege man
###### 472 | ### do sprach div chvniginne | wi ist daz geschen ### daz ir habt her sifrit | der spil niht gesehen ### div hie hat errvngen | div gvntheres hant ### des antwurte in hagene | vzer bvrgvnden lant
###### 473 | ### er sprach da hete ir vns vrowe | betrivbet den mvt ### do was bi dem scheffe | sifrit der helt gvt ### do der vogt von rine | div spil iv an gewan ### des ist ez im vnchvnde | sprach der gvntheres man
###### 474 | ### do wol mich dirre maere | sprach sifrit der daegen ### daz iwer hochvart | ist also hie gelaegen ### daz iemen lebet der iwer | meister mvege sin ### nvo svlt ir magt edele | vns hinnen volgen an den rin
###### 475 | ### do sprach div wolgetane | des en mach niht ergan ### ez mivezen e bevinden | mage vnt mine man ### ia ne mag ich also lihte | gervmen minvo lant ### di mine besten frivnde | werden e besant
###### 476 | ### do hiez si boten riten | allenthalben dan ### si besande ir vrivnde | mage vnd man ### di bat si ce isensteine | chomen vnerwant ### vnt hiez in allen gaeben | rich vnt herlich gewant
###### 477 | ### si ritten taegeliche | spate vnt vrv ### der prvnnhilde bverge | scharhaft zv ### iara ia sprach hagene | waz haben wir getan ### wir rebeiten hie vil vebele | der schonen prvnnhilde man
###### 478 | ### so si nv mit ir chrepfte | choment in daz lant ### der chvneginne wille | ist vns vnbechant ### waz ob si also zvrnet | daz wir sin verlorn ### so ist vns div magt edele | ce grozzen sorgen geborn
###### 479 | ### do sprach der starche sifrit | daz sol ich vndersten ### des ir da habt sorge | des laz ich niht ergen ### ich sol iv helffe bringen | her in diz lant ### vil erwelten rechen | die iv noch nie wurden bechant
###### 480 | ### ir svlt nach mir niht vragen | ich wil hinnen varn ### got mievz iwer ere | di zit wol bewarn ### ich chvm schiere wider | vnt bringe tvsent man ### der allerbesten daegene | der ich ie chvende gewan
###### 481 | ### do ne sit et niht ce lange | sprach der chvenich do ### wir sin iwerr helffe | vil pillichen vro ### er sprach ich chvm wider | in vil chvrcen tagen ### daz ir mich habt gesendet | daz svlt ir prvnnhilde sagen

<<< Übersicht <<< vorige Seite nächste Seite >>>